@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bcddbhttpquery.h 346793 2004-09-15 20:46:23Z trueg $
+ * $Id: k3bcddbhttpquery.h 496987 2006-01-11 16:20:53Z larkang $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -56,7 +56,7 @@ class K3bCddbHttpQuery : public K3bCddbQuery
 
   QString m_currentlyConnectingServer;
 
-  QString m_data;
+  QByteArray m_data;
   QString m_parsingBuffer;
 };
 
