@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdefaultexternalprograms.cpp 426565 2005-06-17 18:05:08Z trueg $
+ * $Id: k3bdefaultexternalprograms.cpp 471081 2005-10-16 10:55:47Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -219,6 +219,9 @@ bool K3bCdrecordProgram::scan( const QString& p )
   if( bin->version > K3bVersion("1.11a17") )
     bin->addFeature( "hacked-atapi" );
 
+  if( bin->version >= K3bVersion( 2, 1, 1, "a02" ) )
+    bin->addFeature( "short-track-raw" );
+
   addBin( bin );
   return true;
 }
