@@ -627,7 +627,11 @@ void K3bCdCopyJob::readNextSession()
     d->dataTrackReader->setIgnoreErrors( m_ignoreReadErrors );
     d->dataTrackReader->setNoCorrection( m_noCorrection );
     d->dataTrackReader->setRetries( m_readRetries );
-    
+    if( m_onlyCreateImages )
+      d->dataTrackReader->setSectorSize( K3bDataTrackReader::MODE1 );
+    else
+      d->dataTrackReader->setSectorSize( K3bDataTrackReader::AUTO );
+
     K3bTrack* track = 0;
     unsigned int dataTrackIndex = 0;
     if( d->toc.contentType() == K3bDevice::MIXED ) {
@@ -856,6 +860,17 @@ bool K3bCdCopyJob::writeNextSession()
     //
     // Data Session
     //
+    K3bTrack* track = 0;
+    unsigned int dataTrackIndex = 0;
+    if( d->toc.contentType() == K3bDevice::MIXED ) {
+      track = &d->toc[d->toc.count()-1];
+      dataTrackIndex = 0;
+    }
+    else {
+      track = &d->toc[d->currentWrittenSession-1];
+      dataTrackIndex = d->currentWrittenSession-1;
+    }
+
     bool multi = d->doNotCloseLastSession || (d->numSessions > 1 && d->currentWrittenSession < d->toc.count());
     int usedWritingMode = m_writingMode;
     if( usedWritingMode == K3b::WRITING_MODE_AUTO ) {
@@ -863,7 +878,8 @@ bool K3bCdCopyJob::writeNextSession()
       k3bcore->config()->setGroup("General Options");
       if( m_writerDevice->dao() &&
 	  d->toc.count() == 1 && 
-	  !multi )
+	  !multi &&
+	  track->mode() == K3bDevice::Track::MODE1 )
  	usedWritingMode = K3b::DAO;
       else
 	usedWritingMode = K3b::TAO;
@@ -881,17 +897,6 @@ bool K3bCdCopyJob::writeNextSession()
     if( m_onTheFly )
       d->cdrecordWriter->addArgument( "-waiti" );
 
-    K3bTrack* track = 0;
-    unsigned int dataTrackIndex = 0;
-    if( d->toc.contentType() == K3bDevice::MIXED ) {
-      track = &d->toc[d->toc.count()-1];
-      dataTrackIndex = 0;
-    }
-    else {
-      track = &d->toc[d->currentWrittenSession-1];
-      dataTrackIndex = d->currentWrittenSession-1;
-    }
-
     if( track->mode() == K3bDevice::Track::MODE1 )
       d->cdrecordWriter->addArgument( "-data" );
     else if( track->mode() == K3bDevice::Track::XA_FORM1 )
@@ -918,6 +923,9 @@ bool K3bCdCopyJob::writeNextSession()
       d->cdrecordWriter->addArgument( d->imageNames[d->toc.count()-1] );
     else
       d->cdrecordWriter->addArgument( d->imageNames[d->currentWrittenSession-1] );
+
+    // clear cd text from previous sessions
+    d->cdrecordWriter->setRawCdText( QByteArray() );
   }
 
 
@@ -952,8 +960,14 @@ void K3bCdCopyJob::slotSessionReaderFinished( bool success )
 	d->readingSuccessful = true;
 	if( !m_onlyCreateImages ) {
 	  if( m_readerDevice == m_writerDevice ) {
-	    // eject the media
-	    K3bDevice::eject( m_readerDevice );
+	    // eject the media (we do this blocking to know if it worked
+	    // becasue if it did not it might happen that k3b overwrites a CD-RW
+	    // source)
+	    if( !m_readerDevice->eject() ) {
+	      emit infoMessage( i18n("Unable to eject media."), ERROR );
+	      finishJob( false, true );
+	      return;
+	    }
 	  }
 	  
 	  if( !writeNextSession() ) {
