@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdvdcopyjob.cpp 426858 2005-06-18 18:14:20Z trueg $
+ * $Id: k3bdvdcopyjob.cpp 526893 2006-04-05 21:23:45Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -144,14 +144,14 @@ void K3bDvdCopyJob::slotDiskInfoReady( K3bDevice::DeviceHandler* dh )
       bool haveLibdvdcss = false;
       kdDebug() << "(K3bDvdCopyJob) trying to open libdvdcss." << endl;
       if( K3bLibDvdCss* libcss = K3bLibDvdCss::create() ) {
-	kdDebug() << "(K3bLibDvdCss) succeeded." << endl;
-	kdDebug() << "(K3bLibDvdCss) dvdcss_open(" << m_readerDevice->blockDeviceName() << ") = "
+	kdDebug() << "(K3bDvdCopyJob) succeeded." << endl;
+	kdDebug() << "(K3bDvdCopyJob) dvdcss_open(" << m_readerDevice->blockDeviceName() << ") = "
 		  << libcss->open(m_readerDevice) << endl;
 	haveLibdvdcss = true;
 	delete libcss;
       }
       else
-	kdDebug() << "(K3bLibDvdCss) failed." << endl;
+	kdDebug() << "(K3bDvdCopyJob) failed." << endl;
 
       if( !haveLibdvdcss ) {
 	emit infoMessage( i18n("Cannot copy encrypted DVDs."), ERROR );
@@ -187,7 +187,8 @@ void K3bDvdCopyJob::slotDiskInfoReady( K3bDevice::DeviceHandler* dh )
     case K3bDevice::MEDIA_DVD_R_DL_SEQ:
     case K3bDevice::MEDIA_DVD_R_DL_JUMP:
       if( !m_onlyCreateImage ) {
-	if( dh->diskInfo().numLayers() > 1 ) {
+	if( dh->diskInfo().numLayers() > 1 && 
+	    dh->diskInfo().size().mode1Bytes() > 4700372992LL ) {
 	  if( !(m_writerDevice->type() & (K3bDevice::DEVICE_DVD_R_DL|K3bDevice::DEVICE_DVD_PLUS_R_DL)) ) {
 	    emit infoMessage( i18n("The writer does not support writing Double Layer DVD."), ERROR );
 	    d->running = false;
@@ -506,7 +507,17 @@ void K3bDvdCopyJob::slotReaderFinished( bool success )
     }
     else {
       if( m_writerDevice == m_readerDevice )
-	m_readerDevice->eject();
+	// eject the media (we do this blocking to know if it worked
+	// becasue if it did not it might happen that k3b overwrites a CD-RW
+	// source)
+	if( !m_readerDevice->eject() ) {
+	  emit infoMessage( i18n("Unable to eject media."), ERROR );
+	  if( m_removeImageFiles )
+	    removeImageFiles();
+	  d->running = false;
+	  emit finished(false);
+	  return;
+	}
 
       if( !m_onTheFly ) {
 	if( waitForDvd() ) {
@@ -526,8 +537,8 @@ void K3bDvdCopyJob::slotReaderFinished( bool success )
 	    removeImageFiles();
 	  if( d->canceled )
 	    emit canceled();
-	  emit finished(false);
 	  d->running = false;
+	  emit finished(false);
 	}
       }
     }
@@ -618,7 +629,8 @@ bool K3bDvdCopyJob::waitForDvd()
   // in case the source is a double layer DVD we made sure above that the writer
   // is capable of writing DVD+R-DL or DVD-R DL and here we wait for a DL DVD
   //
-  if( d->sourceDiskInfo.numLayers() > 1 ) {
+  if( d->sourceDiskInfo.numLayers() > 1  &&
+      d->sourceDiskInfo.size().mode1Bytes() > 4700372992LL ) {
     mt = K3bDevice::MEDIA_WRITABLE_DVD_DL;
   }
 
