@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3baudiodoc.cpp 448840 2005-08-13 09:25:01Z trueg $
+ * $Id: k3baudiodoc.cpp 478440 2005-11-06 19:59:44Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -174,7 +174,7 @@ void K3bAudioDoc::addUrls( const KURL::List& urls )
 
 void K3bAudioDoc::addTracks( const KURL::List& urls, uint position )
 {
-  KURL::List allUrls = extractUrlList( urls );
+  KURL::List allUrls = extractUrlList( K3b::convertToLocalUrls(urls) );
   for( KURL::List::iterator it = allUrls.begin(); it != allUrls.end(); it++, position++ ) {
     KURL& url = *it;
     if( url.path().right(3).lower() == "cue" ) {
@@ -651,6 +651,9 @@ bool K3bAudioDoc::loadDocumentData( QDomElement* root )
 	    }
 	  }
 
+	  else if( trackNodes.item(trackJ).nodeName() == "index0" )
+	    track->setIndex0( K3b::Msf::fromString( trackNodes.item(trackJ).toElement().text() ) );
+
 	  // load options
 	  else if( trackNodes.item(trackJ).nodeName() == "copy_protection" )
 	    track->setCopyProtection( trackNodes.item(trackJ).toElement().text() == "yes" );
