@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdataverifyingjob.h 330821 2004-07-19 09:15:18Z trueg $
+ * $Id: k3bdataverifyingjob.h 475317 2005-10-28 21:06:04Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -17,6 +17,8 @@
 #define _K3B_DATA_VERIFYING_JOB_H_
 
 #include <k3bjob.h>
+#include "k3bdatadoc.h"
+
 
 class K3bDataDoc;
 namespace KIO {
@@ -43,6 +45,7 @@ class K3bDataVerifyingJob : public K3bJob
 
   void setDoc( K3bDataDoc* );
   void setDevice( K3bDevice::Device* );
+  void setUsedMultiSessionMode( K3bDataDoc::MultiSessionMode );
 
  private slots:
   void slotMediaReloaded( bool );
