@@ -1,6 +1,6 @@
 /*
 *
-* $Id: k3bvcddoc.cpp 397910 2005-03-15 21:42:43Z trueg $
+* $Id: k3bvcddoc.cpp 474610 2005-10-26 20:49:57Z trueg $
 * Copyright (C) 2003-2005 Christian Kvasny <chris@k3b.org>
 *
 * This file is part of the K3b project.
@@ -139,7 +139,7 @@ void K3bVcdDoc::addUrls( const KURL::List& urls )
 void K3bVcdDoc::addTracks( const KURL::List& urls, uint position )
 {
     for ( KURL::List::ConstIterator it = urls.begin(); it != urls.end(); it++ ) {
-        urlsToAdd.enqueue( new PrivateUrlToAdd( *it, position++ ) );
+      urlsToAdd.enqueue( new PrivateUrlToAdd( K3b::convertToLocalUrl(*it), position++ ) );
     }
 
     m_urlAddingTimer->start( 0 );
