@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdevice.h 421129 2005-06-02 09:33:12Z trueg $
+ * $Id: k3bdevice.h 543494 2006-05-22 08:32:30Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -402,18 +402,12 @@ namespace K3bDevice
        */
       int currentProfile() const;
 
-      /**
-       * @returns true if the requested feature is supported and also current.
-       * @deprecated use featureCurrent
-       */
-      bool supportsFeature( unsigned int feature ) const;
-
       /**
        * Check if a certain feature is current.
        * \see k3bdevicetypes.h for feature constants.
-       * \return true if the feature and false otherwise (this includes errors)
+       * \return 1 if the feature is current, 0 if not, -1 on error
        */
-      bool featureCurrent( unsigned int feature ) const;
+      int featureCurrent( unsigned int feature ) const;
 
       /**
        * This is the method to use!
@@ -790,7 +784,7 @@ namespace K3bDevice
       friend class DeviceManager;
     };
 
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_NETBSD)
   /**
    * This should always be used to open a device since it
    * uses the resmgr
