@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdiroperator.h,v 1.3.2.1 2004/05/17 17:39:14 trueg Exp $
+ * $Id: k3bdiroperator.h 442567 2005-08-03 07:42:59Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -18,15 +18,19 @@
 #define K3BDIROPERATOR_H
 
 #include <kdiroperator.h>
+#include <kbookmarkmanager.h>
 
 class QIconViewItem;
 class QListViewItem;
+class KBookmarkMenu;
+class KActionMenu;
+
 
 
 /**
   *@author Sebastian Trueg
   */
-class K3bDirOperator : public KDirOperator
+class K3bDirOperator : public KDirOperator, public KBookmarkOwner
 {
   Q_OBJECT
 
@@ -44,15 +48,35 @@ class K3bDirOperator : public KDirOperator
    */
   void writeConfig( KConfig* cfg, const QString& group );
 
- signals:
-  void doubleClicked( KFileItem* item );
+  /**
+   * reimplemented from KBookmarkOwner
+   */
+  void openBookmarkURL( const QString& url );
 
- protected:
-  KFileView* createView( QWidget* parent, KFile::FileView view );
+  /**
+   * reimplemented from KBookmarkOwner
+   */
+  QString currentTitle() const;
+
+  /**
+   * reimplemented from KBookmarkOwner
+   */
+  QString currentURL() const;
+
+  KActionMenu* bookmarkMenu() const { return m_bmPopup; }
+
+ public slots:
+  void slotAddFilesToProject();
 
  protected slots:
-  void slotIconViewItemDoubleClicked( QIconViewItem* );
-  void slotListViewItemDoubleClicked( QListViewItem* );
+  /**
+   * reimplemented from KDirOperator
+   */
+  void activatedMenu( const KFileItem*, const QPoint& );
+
+ private:
+  KBookmarkMenu* m_bmMenu;
+  KActionMenu* m_bmPopup;
 };
 
 #endif
