@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bfiletreeview.cpp 366987 2004-11-28 20:49:22Z trueg $
+ * $Id: k3bfiletreeview.cpp 527717 2006-04-09 08:45:21Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -63,6 +63,19 @@ K3bDeviceBranch::K3bDeviceBranch( KFileTreeView* view, K3bDevice::Device* dev, K
 }
 
 
+
+bool K3bDeviceBranch::populate( const KURL& url,  KFileTreeViewItem *currItem )
+{
+  // make sure we do not try to populate in case we are not mounted
+  if( !KIO::findDeviceMountPoint( m_device->mountDevice() ).isEmpty() )
+    return KFileTreeBranch::populate( url, currItem );
+  else
+    populateFinished( currItem );
+
+  return true;
+}
+
+
 void K3bDeviceBranch::showBlockDeviceName( bool b )
 {
   if( b )
