@@ -329,8 +329,7 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
   }
 
   case K3bDoc::DATA:
-  case K3bDoc::DVD:
-  case K3bDoc::VIDEODVD: {
+  case K3bDoc::DVD: {
     K3bDataDoc* dataDoc = static_cast<K3bDataDoc*>(doc);
 
     dataDoc->setIsoOptions( K3bIsoOptions::load( c ) );
@@ -360,6 +359,12 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
     break;
   }
 
+  case K3bDoc::VIDEODVD: {
+    K3bDataDoc* dataDoc = static_cast<K3bDataDoc*>(doc);
+    dataDoc->setIsoOptions( K3bIsoOptions::load( c ) );
+    break;
+  }
+
   case K3bDoc::MIXED: {
     K3bMixedDoc* mixedDoc = static_cast<K3bMixedDoc*>(doc);
 
@@ -415,6 +420,8 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
     if( static_cast<K3bDataDoc*>(doc)->isoOptions().volumeID().isEmpty() )
       static_cast<K3bDataDoc*>(doc)->setVolumeID( doc->URL().path() );
   }
+
+  doc->setModified( false );
 }
 
 
