@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bprojecttabwidget.cpp,v 1.5.2.1 2004/01/31 17:08:18 trueg Exp $
+ * $Id: k3bprojecttabwidget.cpp 397910 2005-03-15 21:42:43Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -17,12 +17,15 @@
 
 #include "k3bprojecttabwidget.h"
 #include "k3bprojecttabbar.h"
+#include "k3bapplication.h"
+#include "k3bprojectmanager.h"
 
 #include <k3bview.h>
 #include <k3bdoc.h>
 
 #include <kaction.h>
-
+#include <kiconloader.h>
+#include <kdebug.h>
 
 
 K3bProjectTabWidget::K3bProjectTabWidget( QWidget *parent, const char *name, WFlags f )
@@ -40,6 +43,18 @@ K3bProjectTabWidget::~K3bProjectTabWidget()
 }
 
 
+void K3bProjectTabWidget::insertTab( K3bDoc* doc )
+{
+  QTabWidget::insertTab( doc->view(), doc->URL().fileName(), 0 );
+  connect( k3bappcore->projectManager(), SIGNAL(projectSaved(K3bDoc*)), this, SLOT(slotDocSaved(K3bDoc*)) );
+  connect( doc, SIGNAL(changed(K3bDoc*)), this, SLOT(slotDocChanged(K3bDoc*)) );
+  if( doc->isModified() )
+    slotDocChanged( doc );
+  else
+    slotDocSaved( doc );
+}
+
+
 void K3bProjectTabWidget::slotUrlsDropped( int id, const KURL::List& urls )
 {
   QWidget* w = page( m_tabBar->indexOf( id ) );
@@ -54,5 +69,17 @@ void K3bProjectTabWidget::insertAction( KAction* action )
 }
 
 
+void K3bProjectTabWidget::slotDocChanged( K3bDoc* doc )
+{
+  setTabIconSet( doc->view(), SmallIconSet( "filesave" ) );
+  changeTab( doc->view(), doc->URL().fileName() );
+}
+
+
+void K3bProjectTabWidget::slotDocSaved( K3bDoc* doc )
+{
+  setTabIconSet( doc->view(), QIconSet() );
+}
+
 #include "k3bprojecttabwidget.moc"
 
