@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bwelcomewidget.cpp 443744 2005-08-07 08:45:42Z mlaurent $
+ * $Id: k3bwelcomewidget.cpp 467572 2005-10-05 16:42:24Z trueg $
  * Copyright (C) 2003-2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -381,7 +381,7 @@ void K3bWelcomeWidget::contentsMousePressEvent( QMouseEvent* e )
       // the actionmenu containing all the other file_new actions and that would not make sense
       // on a toolbutton
       QString aname(a->name());
-      if( aname != "file_new"  && aname != "file_new_cd" && aname != "file_new_dvd" &&
+      if( aname != "file_new" &&
 	  ( aname.startsWith( "tools" ) || aname.startsWith( "file_new" ) ) &&
 	  !main->m_actions.containsRef(a) )
 	map.insert( addPop.insertItem( a->iconSet(), a->text() ), a );
