@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bpatternoptiontab.h,v 1.7 2004/01/21 10:20:13 trueg Exp $
+ * $Id: k3bpatternoptiontab.h 325371 2004-07-02 16:39:33Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -19,7 +19,7 @@
 
 #include "base_k3bpatternoptiontab.h"
 
-#include <cddb/k3bcddbquery.h>
+#include <k3bcddbquery.h>
 
 
 /**
