@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bcddbpatternwidget.h,v 1.4 2004/01/21 10:20:20 trueg Exp $
+ * $Id: k3bcddbpatternwidget.h 401319 2005-03-28 16:26:58Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -19,7 +19,7 @@
 
 #include "base_k3bcddbpatternwidget.h"
 
-class KConfig;
+class KConfigBase;
 
 
 class K3bCddbPatternWidget : public base_K3bCddbPatternWidget
@@ -39,9 +39,13 @@ class K3bCddbPatternWidget : public base_K3bCddbPatternWidget
   void changed();
 
  public slots:
-  void loadConfig( KConfig* );
-  void saveConfig( KConfig* );
+  void loadConfig( KConfigBase* );
+  void saveConfig( KConfigBase* );
   void loadDefaults();
+
+ private slots:
+  void slotSeeSpecialStrings();
+  void slotSeeConditionalInclusion();
 };
 
 #endif
