@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdvdrippingprocess.cpp,v 1.32.2.1 2004/06/02 09:31:41 trueg Exp $
+ * $Id: k3bdvdrippingprocess.cpp 423010 2005-06-07 08:32:10Z trueg $
  * Copyright (C) 2003 Thomas Froescher <tfroescher@k3b.org>
  *
  * This file is part of the K3b project.
@@ -38,8 +38,8 @@
 #include <kio/job.h>
 #include <kmessagebox.h>
 
-K3bDvdRippingProcess::K3bDvdRippingProcess( QObject *parent ) 
-  : K3bJob(parent) {
+K3bDvdRippingProcess::K3bDvdRippingProcess( K3bJobHandler* jh, QObject *parent )
+  : K3bJob( jh, parent ) {
     //m_processAudio = processAudio;
   //    m_parent = parent;
 }
@@ -82,17 +82,29 @@ void K3bDvdRippingProcess::checkRippingMode() {
     m_currentRipTitle++;
     m_title = QString::number( (*m_dvd).getTitleNumber() );
     if( (*m_dvd).getMaxAngle() == 1 ) {
-        kdDebug() << "K3bDvdRippingProcess) Rip Title" << endl;
+      kdDebug() << "K3bDvdRippingProcess) Rip Title" << endl;
+      const K3bVersion& tccatVersion = k3bcore->externalBinManager()->binObject("tccat")->version;
+      K3bVersion simpleVersion = tccatVersion.simplify();
+      kdDebug() << "(K3bDvdRippingProcess) Tccat Version: " << tccatVersion.versionString() << endl;
+      if( simpleVersion <= K3bVersion( 0, 6, 11 ) ) {
+	//transcode <= 0.6.11
         m_ripMode = "-P " + m_title;
-    } else {
-        kdDebug() << "K3bDvdRippingProcess) Rip Angle" << endl;
-        // workaround due to buggy transcode, angle selection doesn't work with -1 (all chapters)
-        // and it doesn't work with loop alone, chapters must be from - to = 0-4 or so.
-        // combination of loop and chapter range works with transcode 0.6.2-20021107
-        m_ripMode = "-T " + m_title + ",0-1," + m_angle + " -L";
-        //QStringList::Iterator titleList = (*m_dvd).getAngles()->at( m_currentRipAngle );
-        //m_currentRipAngle++;
-        //m_angle = *titleList;
+      }
+      else {
+	//transcode >= 0.6.12
+	m_ripMode = "-T " + m_title + ",-1 -L";
+      }
+    } 
+    else {
+      kdDebug() << "K3bDvdRippingProcess) Rip Angle" << endl;
+      // workaround due to buggy transcode, angle selection doesn't work with -1 (all chapters)
+      // and it doesn't work with loop alone, chapters must be from - to = 0-4 or so.
+      // combination of loop and chapter range works with transcode 0.6.2-20021107
+      // Is this still working with tccat >=0.6.12 ???
+      m_ripMode = "-T " + m_title + ",0-1," + m_angle + " -L";
+      //QStringList::Iterator titleList = (*m_dvd).getAngles()->at( m_currentRipAngle );
+      //m_currentRipAngle++;
+      //m_angle = *titleList;
     }
     preProcessingDvd();
 }
@@ -120,13 +132,6 @@ void K3bDvdRippingProcess::startRippingProcess( ) {
     m_delAudioProcess = true;
     */
     const K3bExternalBin *m_tccatBin = k3bcore->externalBinManager()->binObject("tccat");
-    if( m_tccatBin->version >= K3bVersion( 0, 6, 12 ) ) {
-      emit infoMessage( i18n("Sorry, K3b does not support ripping Video DVDs with transcode >= 0.1.12 yet."),
-			ERROR );
-      emit finished( false );
-      return;
-    }
-
     m_ripProcess = new KShellProcess();
     kdDebug() << "(K3bDvdRippingProcess)" << m_tccatBin->path << " -i " << m_device <<" "<< m_ripMode << endl;
     *m_ripProcess << m_tccatBin->path << "-i" <<  m_device << m_ripMode;
@@ -162,6 +167,9 @@ void K3bDvdRippingProcess::slotExited( KProcess* ) {
     kdDebug() << "(K3bDvdRippingProcess) Ripping task finsihed." << endl;
     m_outputFile.close();
     delete m_ripProcess;
+    if( m_interrupted )
+      return;
+
     kdDebug() << "(K3bDvdRippingProcess) Ripped bytes: " << m_summaryBytes << endl;
     //m_audioProcess->closeStdin();
     if( m_currentRipTitle < m_maxTitle ) {
@@ -170,7 +178,7 @@ void K3bDvdRippingProcess::slotExited( KProcess* ) {
         kdDebug() << "(K3bDvdRippingProcess) Copy IFO files for audio gain processing." << endl;
         //postProcessingDvd();
         saveConfig();
-	emit infoMessage( i18n("Successfully ripped all video titles to %1.").arg(m_dirvob), SUCCESS );        
+	emit infoMessage( i18n("Successfully ripped all video titles to %1.").arg(m_dirvob), SUCCESS );
         emit finished( true );
         //  postProcessingFinished();
     }
@@ -181,25 +189,19 @@ void K3bDvdRippingProcess::slotParseOutput( KProcess *p, char *text, int len) {
         m_outputFile.close();
         p->kill();
         //m_audioProcess->kill();
+	emit canceled();
         emit finished( false );
         return;
     }
-    m_stream->writeRawBytes( text, len );
-    //m_audioProcess->writeStdin( text, len );
-    m_rippedBytes += len;
-    m_summaryBytes += len;
-    if( m_titleBytes > 0 ) {
-        unsigned int pc = (unsigned int) ((( m_summaryBytes / m_titleBytes) *100)+0.5);
-        if ( pc > m_percent ) {
-            emit percent( pc );
-            m_percent = pc;
-            unsigned long b = (unsigned long) ( m_summaryBytes - m_dataRateBytes );
-            m_dataRateBytes = m_summaryBytes;
-            emit rippedBytesPerPercent( b );
-        }
-    }
-    if( m_rippedBytes >= 1073741824 ) {  // 24
-        m_rippedBytes = 0;
+    if( m_rippedBytes >= 1073740800 ) {  // 24, 1 (1073741824bytes) GB - 1024 bytes
+        kdDebug() << "(K3bDvdRippingProcess) Ripped bytes: " << m_rippedBytes << endl;
+        // only write amount of bytes to reach exacly 1 GB
+        int writeBytes = int (1073741824 - m_rippedBytes);
+        kdDebug() << "(K3bDvdRippingProcess) Write bytes " << writeBytes << " of " << len << endl;
+        m_stream->writeRawBytes( text, writeBytes );
+        // these amount of bytes must be write to the next file
+        m_rippedBytes = 1024 - writeBytes;
+        kdDebug() << "(K3bDvdRippingProcess) To much " << m_rippedBytes << endl;
         p->suspend();
         m_outputFile.close();
         delete m_stream;
@@ -216,12 +218,27 @@ void K3bDvdRippingProcess::slotParseOutput( KProcess *p, char *text, int len) {
             emit canceled();
             return;
         }
-        p->resume(); // restart process
         m_outputFile.open( IO_WriteOnly );                     // open file for writing
         m_stream = new QDataStream( &m_outputFile );                        // serialize using f
+        char *ctext = text+writeBytes;
+        m_stream->writeRawBytes( ctext, (int)m_rippedBytes);
+        p->resume(); // restart process
+    } else {
+        m_stream->writeRawBytes( text, len );
+        //m_audioProcess->writeStdin( text, len );
+        m_rippedBytes += len;
+        m_summaryBytes += len;
+        if( m_titleBytes > 0 ) {
+            unsigned int pc = (unsigned int) ((( m_summaryBytes / m_titleBytes) *100)+0.5);
+            if ( pc > m_percent ) {
+                emit percent( pc );
+                m_percent = pc;
+                unsigned long b = (unsigned long) ( m_summaryBytes - m_dataRateBytes );
+                m_dataRateBytes = m_summaryBytes;
+                emit rippedBytesPerPercent( b );
+            }
+        }
     }
-
-
 }
 
 float K3bDvdRippingProcess::tccatParsedBytes( char *text, int len) {
@@ -238,6 +255,19 @@ float K3bDvdRippingProcess::tccatParsedBytes( char *text, int len) {
         tmp= tmp.mid( 0, end); // end value
         blocks = (tmp.toFloat()-startBlocks)*2048;
     }
+    else if( tmp.contains("From block") ) {
+        int index = tmp.find("From block");
+        tmp = tmp.mid(index+11);
+        int end = tmp.find( " to block " );
+        QString start= tmp.mid( 0, end); // first value
+        float startBlocks = start.toFloat();
+        tmp=tmp.mid(end+10);
+        end = tmp.find( '\n' );
+        if (end > 0)
+           tmp= tmp.mid( 0, end); // end value
+
+        blocks = (tmp.toFloat()-startBlocks)*2048;
+    }
     kdDebug() << "(K3bDvdRippingProcess) Parsed bytes: " << QString::number(blocks, 'f') << endl;
     return blocks;
 }
@@ -245,7 +275,7 @@ float K3bDvdRippingProcess::tccatParsedBytes( char *text, int len) {
 void K3bDvdRippingProcess::preProcessingDvd( ) {
     kdDebug() << "(K3bDvdRippingProcess::preProcessingDVD) Copy IFO files from device: <" << m_device << ">."<< endl;
     if( !m_dvdOrgFilenameDetected ) {
-        K3bDevice *dev = k3bcore->deviceManager()->deviceByName( m_device );
+        K3bDevice::Device *dev = k3bcore->deviceManager()->deviceByName( m_device );
         m_mountPoint = dev->mountPoint();
         if( !m_mountPoint.isEmpty() ) {
             QString mount = KIO::findDeviceMountPoint( m_device );
@@ -253,7 +283,8 @@ void K3bDvdRippingProcess::preProcessingDvd( ) {
             if( mount.isEmpty() ) {
                 kdDebug() << "(K3bDvdRippingProcess) Try to mount <" << m_mountPoint << ">." << endl;
 		emit newSubTask( i18n("Mounting media") );
-                connect( KIO::mount( true, "autofs", "", m_mountPoint, true ),
+		// FIXME: why not use K3bAppDeviceManager
+                connect( KIO::mount( true, 0, dev->mountDevice(), dev->mountPoint(), false ),
                          SIGNAL(result(KIO::Job*)), this, SLOT( slotPreProcessingDvd(KIO::Job*) ) );
             } else {
                 m_mountPoint = mount;
@@ -273,7 +304,7 @@ void K3bDvdRippingProcess::slotPreProcessingDvd( KIO::Job *resultJob) {
     // do show a dialog instead of an infoMessage since the errorString spreads over multible lines. :(
     resultJob->showErrorDialog( qApp->activeWindow() );
     emit infoMessage( i18n("Mounting failed."), ERROR );
-    
+
     m_preProcessingFailed = true;
     emit finished( false );
   } else {
@@ -283,14 +314,18 @@ void K3bDvdRippingProcess::slotPreProcessingDvd( KIO::Job *resultJob) {
 }
 
 void K3bDvdRippingProcess::slotPreProcessingDvd() {
+    emit newSubTask( i18n("Preprocessing Video DVD") );
+
     QString video;
     QDir video_ts( m_mountPoint + "/VIDEO_TS");
-    if( video_ts.exists() ) {
-        m_udfMount = true;
-        kdDebug() << "(K3bDvdRippingProcess) <" << m_mountPoint << "> has UDF filesystem." << endl;
+
+    if( !video_ts.exists() ) {
+      video_ts.setPath( m_mountPoint + "/video_ts");
+      m_udfMount = true;
+      kdDebug() << "(K3bDvdRippingProcess) <" << m_mountPoint << "> has UDF filesystem." << endl;
     }
-    video_ts.setPath( m_mountPoint + "/video_ts");
-    if( !video_ts.exists() && !m_udfMount){
+
+    if( !video_ts.exists() ){
         m_preProcessingFailed = true;
         KMessageBox::error(qApp->activeWindow(), i18n("K3b could not mount the DVD-device. Ensure that you have the rights to mount the DVD-drive and that it supports either iso9660 or udf filesystem."),
                            i18n("I/O Error") );
@@ -300,10 +335,10 @@ void K3bDvdRippingProcess::slotPreProcessingDvd() {
     }
     bool result = false;
     // read directory from /dev/dvd
-    if( !m_mountPoint.isEmpty() && !m_udfMount) {
+    if( !m_mountPoint.isEmpty() && m_udfMount) {
         result = copyIfoFiles("video_ts", "vts", "ifo");
         video = "video_ts";
-    } else if (!m_mountPoint.isEmpty() && m_udfMount) {
+    } else if (!m_mountPoint.isEmpty() ) {
         kdDebug() << "(K3bDvdRippingProcess) UDF DVD mount filessystem." << endl;
         video = "VIDEO_TS";
         result = copyIfoFiles("VIDEO_TS", "VTS", "IFO");
@@ -324,7 +359,7 @@ bool K3bDvdRippingProcess::copyIfoFiles( const QString& video, const QString& vt
         QStringList ifos;  // = video_ts.entryList();
         m_videoCaseSensitive = QString(video + "." +ifo); // dvd norm
         ifos << m_mountPoint + "/" + video + "/" + m_videoCaseSensitive;
-        m_vobCaseSensitive = vts + "_"+formattedTitleset()+"_0." + ifo; // titleset ifo for the current ripped title	
+        m_vobCaseSensitive = vts + "_"+formattedTitleset()+"_0." + ifo; // titleset ifo for the current ripped title
         ifos << m_mountPoint + "/" + video + "/" + m_vobCaseSensitive;
         KURL::List ifoList = KURL::List( ifos );
         KURL dest( m_dirtmp );
@@ -340,14 +375,14 @@ void K3bDvdRippingProcess::slotIfoCopyFinished( KIO::Job *job ) {
     if( job->error() > 0 ) {
         kdDebug() << "(K3bDvdRippingProcess) Job error IFO copy: " << job->errorString() << endl;
         emit finished( false );
-        KIO::unmount( m_mountPoint, true );
+        KIO::unmount( m_mountPoint, false );
         return;
     }
     kdDebug() << "(K3bDvdRippingProcess) Chmod: " << m_dirtmp << "/" << m_videoCaseSensitive << endl;
     kdDebug() << "(K3bDvdRippingProcess) Chmod: " << m_dirtmp << "/" << m_vobCaseSensitive << endl;
     KIO::chmod( m_dirtmp + "/" + m_videoCaseSensitive, 0644 );
     KIO::chmod( m_dirtmp + "/" + m_vobCaseSensitive, 0644 );
-    connect( KIO::unmount( m_mountPoint, true ), SIGNAL(result(KIO::Job*)), this, SLOT( slotPreProcessingFinished( KIO::Job* )) );
+    connect( KIO::unmount( m_mountPoint, false ), SIGNAL(result(KIO::Job*)), this, SLOT( slotPreProcessingFinished( KIO::Job* )) );
 }
 
 void K3bDvdRippingProcess::slotPreProcessingFinished( KIO::Job *job ) {
@@ -375,7 +410,7 @@ QString K3bDvdRippingProcess::getFilename() {
 
     QFile destFile( result );
     if( destFile.exists() ) {
-        int button = QMessageBox::critical( 0, i18n("Ripping Error"), i18n("%1 already exists." ).arg(result), i18n("Overwrite"), i18n("Cancel") );
+        int button = QMessageBox::critical( 0, i18n("Ripping Error"), i18n("%1 already exists." ).arg(result), i18n("Overwrite"), i18n("&Cancel") );
         if( button == 0 )
             return result;
         else
